@@ -1,4 +1,5 @@
 /*
+ *  Copyright (C) 2015 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2007-2009 Sourcefire, Inc.
  *
  *  Authors: Tomasz Kojm, Trog, Török Edvin
@@ -28,7 +29,7 @@
 #include <stdlib.h>
 #include "shared/optparser.h"
 #include "thrmgr.h"
-#include "cltypes.h"
+#include "clamav-types.h"
 
 enum mode {
     MODE_COMMAND,
@@ -82,12 +83,4 @@ void fds_cleanup(struct fd_data *data);
 int fds_poll_recv(struct fd_data *data, int timeout, int check_signals, void *event);
 void fds_free(struct fd_data *data);
 
-void detstats_clear(void);
-void detstats_add(const char *virname, const char *fname, unsigned int fsize, const char *md5);
-void detstats_print(int desc, char term);
-
-#ifdef FANOTIFY
-int fan_checkowner(int pid, const struct optstruct *opts);
-#endif
-
 #endif
