@@ -1,4 +1,5 @@
 /*
+ *  Copyright (C) 2015, 2017 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2007-2009 Sourcefire, Inc.
  *
  *  Authors: Tomasz Kojm, Török Edvin
@@ -53,6 +54,7 @@
 #include "libclamav/others.h"
 #include "libclamav/scanners.h"
 
+#include "shared/idmef_logging.h"
 #include "shared/optparser.h"
 #include "shared/output.h"
 #include "shared/misc.h"
@@ -76,6 +78,8 @@ void msg_callback(enum cl_msg severity, const char *fullmsg, const char *msg, vo
     struct cb_context *c = ctx;
     const char *filename = (c && c->filename) ? c->filename : "";
 
+    UNUSEDPARAM(fullmsg);
+
     switch (severity) {
 	case CL_MSG_ERROR:
 	    logg("^[LibClamAV] %s: %s", filename, msg);
@@ -95,19 +99,47 @@ void msg_callback(enum cl_msg severity, const char *fullmsg, const char *msg, vo
 void hash_callback(int fd, unsigned long long size, const unsigned char *md5, const char *virname, void *ctx)
 {
     struct cb_context *c = ctx;
+    UNUSEDPARAM(fd);
+    UNUSEDPARAM(virname);
+
     if (!c)
 	return;
     c->virsize = size;
-    strncpy(c->virhash, md5, 32);
+    strncpy(c->virhash, (const char *)md5, 32);
     c->virhash[32] = '\0';
 }
 
+void clamd_virus_found_cb(int fd, const char *virname, void *ctx)
+{
+    struct cb_context *c = ctx;
+    struct scan_cb_data *d = c->scandata;
+    const char *fname;
+    
+    if (d == NULL)
+        return;
+    if (!(d->options->general & CL_SCAN_GENERAL_ALLMATCHES) && !(d->options->general & CL_SCAN_GENERAL_HEURISTIC_PRECEDENCE))
+        return;
+    if (virname == NULL)
+        return;
+
+    fname = (c && c->filename) ? c->filename : "(filename not set)";
+
+    if (virname) {
+        d->infected++;
+        conn_reply_virus(d->conn, fname, virname);
+        if(c->virsize > 0 && optget(d->opts, "ExtendedDetectionInfo")->enabled)
+            logg("~%s: %s(%s:%llu) FOUND\n", fname, virname, c->virhash, c->virsize);
+        logg("~%s: %s FOUND\n", fname, virname);
+    }
+
+    return;
+}
+
 #define BUFFSIZE 1024
 int scan_callback(STATBUF *sb, char *filename, const char *msg, enum cli_ftw_reason reason, struct cli_ftw_cbdata *data)
 {
     struct scan_cb_data *scandata = data->data;
     const char *virname = NULL;
-    const char **virpp = &virname;
     int ret;
     int type = scandata->type;
     struct cb_context context;
@@ -228,18 +260,12 @@ int scan_callback(STATBUF *sb, char *filename, const char *msg, enum cli_ftw_rea
     thrmgr_setactivetask(filename, NULL);
     context.filename = filename;
     context.virsize = 0;
-    ret = cl_scanfile_callback(filename, virpp, &scandata->scanned, scandata->engine, scandata->options, &context);
+    context.scandata = scandata;
+    ret = cl_scanfile_callback(filename, &virname, &scandata->scanned, scandata->engine, scandata->options, &context);
     thrmgr_setactivetask(NULL, NULL);
 
-    if (scandata->options & CL_SCAN_ALLMATCHES) {
-	virpp = (const char **)*virpp; /* temp hack for scanall mode until api augmentation */
-	if (virpp) virname = virpp[0];
-    }
-
     if (thrmgr_group_need_terminate(scandata->conn->group)) {
 	free(filename);
-	if ((scandata->options & CL_SCAN_ALLMATCHES) && (virpp != &virname))
-	    free((void *)virpp);
 	logg("*Client disconnected while scanjob was active\n");
 	return ret == CL_ETIMEOUT ? ret : CL_BREAK;
     }
@@ -250,40 +276,31 @@ int scan_callback(STATBUF *sb, char *filename, const char *msg, enum cli_ftw_rea
     }
 
     if (ret == CL_VIRUS) {
-	scandata->infected++;
-	if (conn_reply_virus(scandata->conn, filename, virname) == -1) {
-	    free(filename);
-	    if((scandata->options & CL_SCAN_ALLMATCHES) && (virpp != &virname))
-		free((void *)virpp);
-	    return CL_ETIMEOUT;
-	}
-	if (scandata->options & CL_SCAN_ALLMATCHES && virpp[1] != NULL) {
-	    int i = 1;
-	    while (NULL != virpp[i])
-		if (conn_reply_virus(scandata->conn, filename, virpp[i++]) == -1) {
-		    free(filename);
-		    if (virpp != &virname)
-			free((void *)virpp);
-		    return CL_ETIMEOUT;
-		}
-	}
-	if(context.virsize)
-	    detstats_add(virname, filename, context.virsize, context.virhash);
-	if(context.virsize && optget(scandata->opts, "ExtendedDetectionInfo")->enabled)
-	    logg("~%s: %s(%s:%llu) FOUND\n", filename, virname, context.virhash, context.virsize);
-	else
-	    logg("~%s: %s FOUND\n", filename, virname);
-	virusaction(filename, virname, scandata->opts);
-	if (scandata->options & CL_SCAN_ALLMATCHES && virpp[1] != NULL) {
-	    int i = 1;
-	    while (NULL != virpp[i])
-                logg("~%s: %s FOUND\n", filename, virpp[i++]);
-	}
+
+         if (scandata->options->general & CL_SCAN_GENERAL_ALLMATCHES || (scandata->infected && scandata->options->general & CL_SCAN_GENERAL_HEURISTIC_PRECEDENCE)) {
+            if(optget(scandata->opts, "PreludeEnable")->enabled){
+                prelude_logging(filename, virname, context.virhash, context.virsize);
+            }
+            virusaction(filename, virname, scandata->opts);
+        } else {
+           scandata->infected++;
+            if (conn_reply_virus(scandata->conn, filename, virname) == -1) {
+                free(filename);
+                return CL_ETIMEOUT;
+            }
+            if(optget(scandata->opts, "PreludeEnable")->enabled){
+                prelude_logging(filename, virname, context.virhash, context.virsize);
+            }
+
+            if(context.virsize && optget(scandata->opts, "ExtendedDetectionInfo")->enabled)
+                logg("~%s: %s(%s:%llu) FOUND\n", filename, virname, context.virhash, context.virsize);
+            else
+                logg("~%s: %s FOUND\n", filename, virname);
+            virusaction(filename, virname, scandata->opts);
+        }
     } else if (ret != CL_CLEAN) {
 	scandata->errors++;
 	if (conn_reply(scandata->conn, filename, cl_strerror(ret), "ERROR") == -1) {
-	    if((scandata->options & CL_SCAN_ALLMATCHES) && (virpp != &virname))
-		free((void *)virpp);
 	    free(filename);
 	    return CL_ETIMEOUT;
 	}
@@ -293,8 +310,7 @@ int scan_callback(STATBUF *sb, char *filename, const char *msg, enum cli_ftw_rea
     }
 
     free(filename);
-    if((scandata->options & CL_SCAN_ALLMATCHES) && (virpp != &virname))
-	free((void *)virpp);
+
     if(ret == CL_EMEM) /* stop scanning */
 	return ret;
 
@@ -337,17 +353,24 @@ int scan_pathchk(const char *path, struct cli_ftw_cbdata *data)
     return 0;
 }
 
-int scanfd(const client_conn_t *conn, unsigned long int *scanned,
-	   const struct cl_engine *engine,
-	   unsigned int options, const struct optstruct *opts, int odesc, int stream)
+int scanfd(
+	const client_conn_t *conn,
+	unsigned long int *scanned,
+	const struct cl_engine *engine,
+	struct cl_scan_options *options,
+	const struct optstruct *opts,
+	int odesc,
+	int stream)
 {
     int ret, fd = conn->scanfd;
-	const char *virname;
+	const char *virname = NULL;
 	STATBUF statbuf;
 	struct cb_context context;
 	char fdstr[32];
 	const char*reply_fdstr;
 
+    UNUSEDPARAM(odesc);
+
 	if (stream) {
 	    struct sockaddr_in sa;
 	    socklen_t salen = sizeof(sa);
@@ -370,7 +393,8 @@ int scanfd(const client_conn_t *conn, unsigned long int *scanned,
 	thrmgr_setactivetask(fdstr, NULL);
 	context.filename = fdstr;
 	context.virsize = 0;
-	ret = cl_scandesc_callback(fd, &virname, scanned, engine, options, &context);
+	context.scandata = NULL;
+	ret = cl_scandesc_callback(fd, NULL, &virname, scanned, engine, options, &context);
 	thrmgr_setactivetask(NULL, NULL);
 
 	if (thrmgr_group_need_terminate(conn->group)) {
@@ -381,8 +405,6 @@ int scanfd(const client_conn_t *conn, unsigned long int *scanned,
 	if(ret == CL_VIRUS) {
 		if (conn_reply_virus(conn, reply_fdstr, virname) == -1)
 		    ret = CL_ETIMEOUT;
-		if(context.virsize)
-		    detstats_add(virname, "NOFNAME", context.virsize, context.virhash);
 		if(context.virsize && optget(opts, "ExtendedDetectionInfo")->enabled)
 		    logg("%s: %s(%s:%llu) FOUND\n", fdstr, virname, context.virhash, context.virsize);
 		else
@@ -401,14 +423,20 @@ int scanfd(const client_conn_t *conn, unsigned long int *scanned,
 	return ret;
 }
 
-int scanstream(int odesc, unsigned long int *scanned, const struct cl_engine *engine, unsigned int options, const struct optstruct *opts, char term)
+int scanstream(
+	int odesc,
+	unsigned long int *scanned,
+	const struct cl_engine *engine,
+	struct cl_scan_options *options,
+	const struct optstruct *opts,
+	char term)
 {
 	int ret, sockfd, acceptd;
 	int tmpd, bread, retval, firsttimeout, timeout, btread;
 	unsigned int port = 0, portscan, min_port, max_port;
 	unsigned long int quota = 0, maxsize = 0;
 	short bound = 0;
-	const char *virname;
+	const char *virname = NULL;
 	char buff[FILEBUFF];
 	char peer_addr[32];
 	struct cb_context context;
@@ -535,12 +563,13 @@ int scanstream(int odesc, unsigned long int *scanned, const struct cl_engine *en
     }
 
     if(retval == 1) {
-	lseek(tmpd, 0, SEEK_SET);
-	thrmgr_setactivetask(peer_addr, NULL);
-	context.filename = peer_addr;
-	context.virsize = 0;
-	ret = cl_scandesc_callback(tmpd, &virname, scanned, engine, options, &context);
-	thrmgr_setactivetask(NULL, NULL);
+		lseek(tmpd, 0, SEEK_SET);
+		thrmgr_setactivetask(peer_addr, NULL);
+		context.filename = peer_addr;
+		context.virsize = 0;
+		context.scandata = NULL;
+		ret = cl_scandesc_callback(tmpd, NULL, &virname, scanned, engine, options, &context);
+		thrmgr_setactivetask(NULL, NULL);
     } else {
     	ret = -1;
     }
@@ -553,8 +582,6 @@ int scanstream(int odesc, unsigned long int *scanned, const struct cl_engine *en
     closesocket(sockfd);
 
     if(ret == CL_VIRUS) {
-	if(context.virsize)
-	    detstats_add(virname, "NOFNAME", context.virsize, context.virhash);
 	if(context.virsize && optget(opts, "ExtendedDetectionInfo")->enabled) {
 	    mdprintf(odesc, "stream: %s(%s:%llu) FOUND%c", virname, context.virhash, context.virsize, term);
 	    logg("stream(%s@%u): %s(%s:%llu) FOUND\n", peer_addr, port, virname, context.virhash, context.virsize);
