@@ -1,4 +1,5 @@
 /*
+ *  Copyright (C) 2015 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2007-2009 Sourcefire, Inc.
  *
  *  Authors: Tomasz Kojm, Török Edvin
@@ -190,7 +191,7 @@ int command(client_conn_t *conn, int *virus)
 {
     int desc = conn->sd;
     struct cl_engine *engine = conn->engine;
-    unsigned int options = conn->options;
+    struct cl_scan_options *options = conn->options;
     const struct optstruct *opts = conn->opts;
     enum scan_type type = TYPE_INIT;
     int maxdirrec;
@@ -368,7 +369,7 @@ int command(client_conn_t *conn, int *virus)
 		return 1;
 	    }
 	    thrmgr_setactivetask(NULL, "ALLMATCHSCAN");
-	    scandata.options |= CL_SCAN_ALLMATCHES;
+	    scandata.options->general |= CL_SCAN_GENERAL_ALLMATCHES;
 	    type = TYPE_SCAN;
 	    break;
 	 default:
@@ -596,12 +597,12 @@ int execute_or_dispatch_command(client_conn_t *conn, enum commands cmd, const ch
 	    }
 	case COMMAND_DETSTATSCLEAR:
 	    {
-		detstats_clear();
+        /* TODO: tell client this command has been removed */
 		return 1;
 	    }
 	case COMMAND_DETSTATS:
 	    {
-		detstats_print(desc, conn->term);
+        /* TODO: tell client this command has been removed */
 		return 1;
 	    }
 	case COMMAND_INSTREAM:
