@@ -1,4 +1,5 @@
 /*
+ *  Copyright (C) 2015 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2007-2008 Sourcefire, Inc.
  *
  *  Authors: Nigel Horne
@@ -18,8 +19,6 @@
  *  MA 02110-1301, USA.
  */
 
-static	char	const	rcsid[] = "$Id: blob.c,v 1.64 2007/02/12 22:25:14 njh Exp $";
-
 #if HAVE_CONFIG_H
 #include "clamav-config.h"
 #endif
@@ -52,7 +51,7 @@ static	char	const	rcsid[] = "$Id: blob.c,v 1.64 2007/02/12 22:25:14 njh Exp $";
 
 #include <assert.h>
 
-/* Scehduled for rewite in 0.94 (bb#804). Disabling for now */
+/* Scheduled for rewrite in 0.94 (bb#804). Disabling for now */
 /* #define	MAX_SCAN_SIZE	20*1024	/\* */
 /* 				 * The performance benefit of scanning */
 /* 				 * early disappears on medium and */
@@ -144,6 +143,8 @@ blobSetFilename(blob *b, const char *dir, const char *filename)
 	assert(b->magic == BLOBCLASS);
 	assert(filename != NULL);
 
+    UNUSEDPARAM(dir);
+
 	cli_dbgmsg("blobSetFilename: %s\n", filename);
 
 	if(b->name)
@@ -456,11 +457,11 @@ fileblobDestroy(fileblob *fb)
 	} else if(fb->b.data) {
 		free(fb->b.data);
 		if(fb->b.name) {
-			cli_errmsg("fileblobDestroy: %s not saved: report to http://bugs.clamav.net\n",
+			cli_errmsg("fileblobDestroy: %s not saved: report to https://bugzilla.clamav.net\n",
 				(fb->fullname) ? fb->fullname : fb->b.name);
 			free(fb->b.name);
 		} else
-			cli_errmsg("fileblobDestroy: file not saved (%lu bytes): report to http://bugs.clamav.net\n",
+			cli_errmsg("fileblobDestroy: file not saved (%lu bytes): report to https://bugzilla.clamav.net\n",
 				(unsigned long)fb->b.len);
 	}
 	if(fb->fullname)
@@ -474,6 +475,8 @@ fileblobDestroy(fileblob *fb)
 void
 fileblobPartialSet(fileblob *fb, const char *fullname, const char *arg)
 {
+    UNUSEDPARAM(arg);
+
 	if(fb->b.name)
 		return;
 
@@ -615,7 +618,9 @@ int
 fileblobScan(const fileblob *fb)
 {
 	int rc;
+	cli_ctx *ctx = fb->ctx;
 	STATBUF sb;
+	int virus_found = 0;
 
 	if(fb->isInfected)
 		return CL_VIRUS;
@@ -633,11 +638,14 @@ fileblobScan(const fileblob *fb)
 	fflush(fb->fp);
 	lseek(fb->fd, 0, SEEK_SET);
 	FSTAT(fb->fd, &sb);
-	if(cli_matchmeta(fb->ctx, fb->b.name, sb.st_size, sb.st_size, 0, 0, 0, NULL) == CL_VIRUS)
-	    return CL_VIRUS;
+	if(cli_matchmeta(fb->ctx, fb->b.name, sb.st_size, sb.st_size, 0, 0, 0, NULL) == CL_VIRUS) {
+            if (!SCAN_ALLMATCHES)
+                return CL_VIRUS;
+            virus_found = 1;
+        }
 
-	rc = cli_magic_scandesc(fb->fd, fb->ctx);
-	if(rc == CL_VIRUS) {
+	rc = cli_magic_scandesc(fb->fd, fb->fullname, fb->ctx);
+	if(rc == CL_VIRUS || virus_found != 0) {
 		cli_dbgmsg("%s is infected\n", fb->fullname);
 		return CL_VIRUS;
 	}
