@@ -1,6 +1,7 @@
 /*
  *  HTML Entity & Encoding normalization.
  *
+ *  Copyright (C) 2015 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2007-2008 Sourcefire, Inc.
  *
  *  Authors: Török Edvin
@@ -35,17 +36,12 @@
 
 #include <assert.h>
 
-#include <openssl/ssl.h>
-#include <openssl/err.h>
-#include "libclamav/crypto.h"
-
 #include "clamav.h"
 #include "others.h"
 #include "htmlnorm.h"
 #include "hashtab.h"
 #include "entconv.h"
 #include "entitylist.h"
-#include "cltypes.h"
 
 #ifdef HAVE_ICONV
 #include <iconv.h>
@@ -715,7 +711,6 @@ static int in_iconv_u16(const m_area_t* in_m_area, iconv_t* iconv_struct, m_area
 	char*  input   = (char*)in_m_area->buffer + in_m_area->offset;
 	size_t outleft = out_m_area->length > 0 ? out_m_area->length : 0;
 	char* out      = (char*)out_m_area->buffer;
-	char err[128];
 
 	out_m_area->offset = 0;
 	if(!inleft) {
