@@ -1,6 +1,7 @@
 /*
  *  A fast filter for static patterns.
  *
+ *  Copyright (C) 2015 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2008 Sourcefire, Inc.
  *
  *  Authors: Török Edvin
@@ -21,7 +22,7 @@
  */
 #ifndef FILTER_H
 #define FILTER_H
-#include "cltypes.h"
+#include "clamav-types.h"
 struct filter {
 	uint8_t B[65536];
 	uint8_t end[65536];
