@@ -1,4 +1,5 @@
 /*
+ *  Copyright (C) 2015 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2007-2008 Sourcefire, Inc.
  *
  *  Authors: Alberto Wu
@@ -21,7 +22,7 @@
 #ifndef __FSG_H
 #define __FSG_H
 
-#include "cltypes.h"
+#include "clamav-types.h"
 #include "execs.h"
 
 int unfsg_200(const char *, char *, int, int, uint32_t, uint32_t, uint32_t, int);
