@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2015 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2015, 2017 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2007-2008 Sourcefire, Inc.
  *
  *  Authors: Michal 'GiM' Spadlinski
@@ -26,7 +26,7 @@
 #include "clamav-config.h"
 #endif
 
-#include "cltypes.h"
+#include "clamav-types.h"
 
 struct lzmastate {
 	const char *p0;
@@ -38,6 +38,6 @@ int mew_lzma(char *, const char *, uint32_t, uint32_t, uint32_t);
 uint32_t lzma_upack_esi_00(struct lzmastate *, char *, char *, uint32_t);
 uint32_t lzma_upack_esi_50(struct lzmastate *, uint32_t, uint32_t, char **, char *, uint32_t *, char *, uint32_t);
 uint32_t lzma_upack_esi_54(struct lzmastate *, uint32_t, uint32_t *, char **, uint32_t *, char *, uint32_t);
-int unmew11(char *, int, int, int, uint32_t, uint32_t, int, int);
+int unmew11(char *, uint32_t, uint32_t, uint32_t, uint32_t, uint32_t, int, int);
 
 #endif
