@@ -1,4 +1,5 @@
 /*
+ *  Copyright (C) 2015 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2007-2008 Sourcefire, Inc.
  *
  *  Authors: Alberto Wu
@@ -53,7 +54,6 @@
 #include <string.h>
 
 #include "clamav.h"
-#include "cltypes.h"
 #include "rebuildpe.h"
 #include "execs.h"
 #include "others.h"
@@ -108,7 +108,8 @@ int petite_inflate2x_1to9(char *buf, uint32_t minrva, uint32_t bufsz, struct cli
   while (1) {
     char *ssrc, *ddst;
     uint32_t size, srva;
-    int backbytes, oldback, backsize, addsize;
+    int backbytes, oldback, addsize;
+    unsigned int backsize;
     
     if ( ! CLI_ISCONTAINED(buf, bufsz, packed, 4)) {
       if (usects)
@@ -275,7 +276,7 @@ int petite_inflate2x_1to9(char *buf, uint32_t minrva, uint32_t bufsz, struct cli
       uint8_t goback;
       unsigned int q;
       
-      /* Unpak each original section in turn */
+      /* Unpack each original section in turn */
 
       if ( ! CLI_ISCONTAINED(buf, bufsz, packed+4, 8)) {
 	if (usects)
@@ -392,6 +393,11 @@ int petite_inflate2x_1to9(char *buf, uint32_t minrva, uint32_t bufsz, struct cli
 	      free(usects);
 	      return 1;
 	    }
+	    if (backbytes >= INT_MAX / 2) {
+		    free(usects);
+		    cli_dbgmsg("Petite: probably invalid file\n");
+		    return 1;
+	    }
 	    backbytes = backbytes*2 + oob;
 	    if ( (oob = doubledl(&ssrc, &mydl, buf, bufsz)) == -1 ) {
 	      free(usects);
@@ -408,6 +414,11 @@ int petite_inflate2x_1to9(char *buf, uint32_t minrva, uint32_t bufsz, struct cli
 		free(usects);
 		return 1;
 	      }
+	      if (backbytes >= INT_MAX / 2) {
+		      free(usects);
+		      cli_dbgmsg("Petite: probably invalid file\n");
+		      return 1;
+	      }
 	      backbytes = backbytes*2 + oob;
 	      backsize--;
 	    } while (backsize);
