@@ -1,4 +1,5 @@
 /*
+ *  Copyright (C) 2015 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2007-2008 Sourcefire, Inc.
  *
  *  Authors: Alberto Wu
@@ -21,7 +22,7 @@
 #ifndef __SPIN_H
 #define __SPIN_H
 
-#include "cltypes.h"
+#include "clamav-types.h"
 #include "rebuildpe.h"
 
 int unspin(char *, int, struct cli_exe_section *, int, uint32_t, int, cli_ctx *);
