@@ -1,6 +1,7 @@
 /*
  *  md5 based hashtab
  *
+ *  Copyright (C) 2015 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2008 Sourcefire, Inc.
  *
  *  Authors: aCaB <acab@clamav.net>
@@ -23,7 +24,7 @@
 #ifndef _UNIQ_H
 #define _UNIQ_H
 
-#include "cltypes.h"
+#include "clamav-types.h"
 
 struct UNIQMD5 {
   struct UNIQMD5 *next;
