@@ -1,6 +1,7 @@
 /*
  *  Extract VBA source code for component MS Office Documents
  *
+ *  Copyright (C) 2015 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2007-2008 Sourcefire, Inc.
  *
  *  Authors: Trog, Nigel Horne
@@ -24,7 +25,7 @@
 #define __VBA_EXTRACT_H
 
 #include "others.h"
-#include "cltypes.h"
+#include "clamav-types.h"
 #include "uniq.h"
 
 typedef struct vba_project_tag {
