@@ -27,11 +27,6 @@
 #include "xar.h"
 #include "fmap.h"
 #if HAVE_LIBXML2
-#ifdef _WIN32
-#ifndef LIBXML_WRITER_ENABLED
-#define LIBXML_WRITER_ENABLED 1
-#endif
-#endif
 #include <libxml/xmlreader.h>
 #include "clamav.h"
 #include "str.h"
@@ -74,14 +69,19 @@ static int xar_cleanup_temp_file(cli_ctx *ctx, int fd, char * tmpname)
 static int xar_get_numeric_from_xml_element(xmlTextReaderPtr reader, size_t * value)
 {
     const xmlChar * numstr;
-    ssize_t numval;
 
     if (xmlTextReaderRead(reader) == 1 && xmlTextReaderNodeType(reader) == XML_READER_TYPE_TEXT) {
         numstr = xmlTextReaderConstValue(reader);
         if (numstr) {
-            numval = atol((const char *)numstr);
-            if (numval < 0) {
-                cli_dbgmsg("cli_scanxar: XML element value %zd\n", numval);
+            long numval;
+            char *endptr = NULL;
+            errno = 0;
+            numval = strtol((const char *)numstr, &endptr, 10);
+            if (((numval == LONG_MAX || numval == LONG_MIN) && errno) || endptr == numstr) {
+                cli_dbgmsg("cli_scanxar: XML element value invalid\n");
+                return CL_EFORMAT;
+            } else if (numval < 0) {
+                cli_dbgmsg("cli_scanxar: XML element value %li\n", numval);
                 return CL_EFORMAT;
             }
             *value = numval;
@@ -280,7 +280,7 @@ static int xar_get_toc_data_values(xmlTextReaderPtr reader, size_t *length, size
      reader - xmlTextReaderPtr
      ctx - pointer to cli_ctx
   Returns:
-     CL_SUCCESS - subdoc found and clean scan (or virus found and SCAN_ALL), or no subdocument
+     CL_SUCCESS - subdoc found and clean scan (or virus found and SCAN_ALLMATCHES), or no subdocument
      other - error return code from cli_mem_scandesc()
 */                        
 static int xar_scan_subdocuments(xmlTextReaderPtr reader, cli_ctx *ctx)
@@ -311,7 +311,7 @@ static int xar_scan_subdocuments(xmlTextReaderPtr reader, cli_ctx *ctx)
             subdoc_len = xmlStrlen(subdoc);
             cli_dbgmsg("cli_scanxar: in-memory scan of xml subdocument, len %i.\n", subdoc_len);
             rc = cli_mem_scandesc(subdoc, subdoc_len, ctx);
-            if (rc == CL_VIRUS && SCAN_ALL)
+            if (rc == CL_VIRUS && SCAN_ALLMATCHES)
                 rc = CL_SUCCESS;
             
             /* make a file to leave if --leave-temps in effect */
@@ -519,7 +519,7 @@ int cli_scanxar(cli_ctx *ctx)
     cli_dbgmsg("cli_scanxar: scanning xar TOC xml in memory.\n"); 
     rc = cli_mem_scandesc(toc, hdr.toc_length_decompressed, ctx);
     if (rc != CL_SUCCESS) {
-        if (rc != CL_VIRUS || !SCAN_ALL)
+        if (rc != CL_VIRUS || !SCAN_ALLMATCHES)
             goto exit_toc;        
     }
 
@@ -846,11 +846,11 @@ int cli_scanxar(cli_ctx *ctx)
                 }
             }
         
-            rc = cli_magic_scandesc(fd, ctx);
+            rc = cli_magic_scandesc(fd, tmpname, ctx);
             if (rc != CL_SUCCESS) {
                 if (rc == CL_VIRUS) {
                     cli_dbgmsg("cli_scanxar: Infected with %s\n", cli_get_last_virus(ctx));
-                    if (!SCAN_ALL)
+                    if (!SCAN_ALLMATCHES)
                         goto exit_tmpfile;
                 } else if (rc != CL_BREAK) {
                     cli_dbgmsg("cli_scanxar: cli_magic_scandesc error %i\n", rc);
