@@ -1,4 +1,5 @@
 /*
+ *  Copyright (C) 2015 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2007-2008 Sourcefire, Inc.
  *
  *  Authors: Ivan Zlatev
@@ -31,21 +32,33 @@
 #include "clamav-config.h"
 #endif
 
-#include <openssl/ssl.h>
-#include <openssl/err.h>
-#include "libclamav/crypto.h"
-
-#include "cltypes.h"
+#include "clamav.h"
 #include "pe.h"
 #include "others.h"
 #include "yc.h"
 
 #define EC16(x) le16_to_host(x) /* Convert little endian to host */
 
+#define DO_HEURISTIC 1
+
+static int yc_bounds_check(cli_ctx *ctx, char *base, unsigned int filesize, char *offset, unsigned int bound)
+{
+      if ((unsigned int)((offset+bound)-base) > filesize) {
+          cli_dbgmsg("yC: Bounds check assertion.\n");
+#if DO_HEURISTIC
+          cli_append_virus(ctx, "Heuristics.BoundsCheck");
+#endif
+          return 1;
+      }
+
+      return 0;
+}
+
+
 /* ========================================================================== */
 /* "Emulates" the poly decryptors */
 
-static int yc_poly_emulator(char* decryptor_offset, char* code, unsigned int ecx, uint32_t max_emu)
+static int yc_poly_emulator(cli_ctx *ctx, char *base, unsigned int filesize, char* decryptor_offset, char* code, unsigned int ecx, uint32_t max_emu)
 {
 
   /* 
@@ -68,18 +81,32 @@ static int yc_poly_emulator(char* decryptor_offset, char* code, unsigned int ecx
   unsigned char al;
   unsigned char cl = ecx & 0xff;
   unsigned int j,i;
+  unsigned int max_jmp_loop = 100000000;
 
   for(i=0;i<ecx&&i<max_emu;i++) /* Byte looper - Decrypts every byte and write it back */
     {
+        if (yc_bounds_check(ctx, base, filesize, code, i)) {
+            return 2;
+        }
       al = code[i];
 
       for(j=0;j<0x30;j++)   /* Poly Decryptor "Emulator" */
 	{
+        if (yc_bounds_check(ctx, base, filesize, decryptor_offset, j)) {
+            return 2;
+        }
+
 	  switch(decryptor_offset[j])
 	    {
 
 	    case '\xEB':	/* JMP short */
 	      j++;
+            if (yc_bounds_check(ctx, base, filesize, decryptor_offset, j)) {
+                return 2;
+            }
+	      if (!max_jmp_loop)
+	          return 2;
+	      max_jmp_loop--;
 	      j = j + decryptor_offset[j];
 	      break;
 
@@ -105,36 +132,57 @@ static int yc_poly_emulator(char* decryptor_offset, char* code, unsigned int ecx
 	      ;
 	    case '\x04':	/* ADD AL,num */
 	      j++;
+            if (yc_bounds_check(ctx, base, filesize, decryptor_offset, j)) {
+                return 2;
+            }
 	      al = al + decryptor_offset[j];
 	      break;
 	      ;
 	    case '\x34':	/* XOR AL,num */
 	      j++;
+            if (yc_bounds_check(ctx, base, filesize, decryptor_offset, j)) {
+                return 2;
+            }
 	      al = al ^ decryptor_offset[j];
 	      break;
 
 	    case '\x2C':	/* SUB AL,num */
 	      j++;
+            if (yc_bounds_check(ctx, base, filesize, decryptor_offset, j)) {
+                return 2;
+            }
 	      al = al - decryptor_offset[j];
 	      break;
 
 			
 	    case '\xC0':
 	      j++;
+            if (yc_bounds_check(ctx, base, filesize, decryptor_offset, j)) {
+                return 2;
+            }
 	      if(decryptor_offset[j]=='\xC0') /* ROL AL,num */
 		{
 		  j++;
+            if (yc_bounds_check(ctx, base, filesize, decryptor_offset, j)) {
+                return 2;
+            }
 		  CLI_ROL(al,decryptor_offset[j]);
 		}
 	      else			/* ROR AL,num */
 		{
 		  j++;
+            if (yc_bounds_check(ctx, base, filesize, decryptor_offset, j)) {
+                return 2;
+            }
 		  CLI_ROR(al,decryptor_offset[j]);
 		}
 	      break;
 
 	    case '\xD2':
 	      j++;
+            if (yc_bounds_check(ctx, base, filesize, decryptor_offset, j)) {
+                return 2;
+            }
 	      if(decryptor_offset[j]=='\xC8') /* ROR AL,CL */
 		{
 		  j++;
@@ -153,11 +201,16 @@ static int yc_poly_emulator(char* decryptor_offset, char* code, unsigned int ecx
 	      break;
 
 	    default:
+            if (yc_bounds_check(ctx, base, filesize, decryptor_offset, j)) {
+                return 2;
+            }
 	      cli_dbgmsg("yC: Unhandled opcode %x\n", (unsigned char)decryptor_offset[j]);
 	      return 1;
 	    }
 	}
       cl--;
+            if (yc_bounds_check(ctx, base, filesize, code, i))
+                return 2;
       code[i] = al;
     }
   return 0;
@@ -168,12 +221,13 @@ static int yc_poly_emulator(char* decryptor_offset, char* code, unsigned int ecx
 /* ========================================================================== */
 /* Main routine which calls all others */
 
-int yc_decrypt(char *fbuf, unsigned int filesize, struct cli_exe_section *sections, unsigned int sectcount, uint32_t peoffset, int desc, uint32_t ecx,int16_t offset) {
+int yc_decrypt(cli_ctx *ctx, char *fbuf, unsigned int filesize, struct cli_exe_section *sections, unsigned int sectcount, uint32_t peoffset, int desc, uint32_t ecx,int16_t offset) {
   uint32_t ycsect = sections[sectcount].raw+offset;
   unsigned int i;
   struct pe_image_file_hdr *pe = (struct pe_image_file_hdr*) (fbuf + peoffset);
   char *sname = (char *)pe + EC16(pe->SizeOfOptionalHeader) + 0x18;
   uint32_t max_emu;
+  unsigned int ofilesize = filesize;
   /* 
 
   First layer (decryptor of the section decryptor) in last section 
@@ -185,8 +239,12 @@ int yc_decrypt(char *fbuf, unsigned int filesize, struct cli_exe_section *sectio
   */
   cli_dbgmsg("yC: offset: %x, length: %x\n", offset, ecx);
   cli_dbgmsg("yC: decrypting decryptor on sect %d\n", sectcount);
-  if (yc_poly_emulator(fbuf + ycsect + 0x93, fbuf + ycsect + 0xc6, ecx, ecx))
-    return 1;
+  switch (yc_poly_emulator(ctx, fbuf, filesize, fbuf + ycsect + 0x93, fbuf + ycsect + 0xc6, ecx, ecx)) {
+  case 2:
+      return CL_VIRUS;
+  case 1:
+      return CL_EUNPACK;
+  }
   filesize-=sections[sectcount].ursz;
 
   /* 
@@ -221,11 +279,15 @@ int yc_decrypt(char *fbuf, unsigned int filesize, struct cli_exe_section *sectio
       cli_dbgmsg("yC: bad emulation length limit %u\n", max_emu);
       return 1;
     }
-    if (yc_poly_emulator(fbuf + ycsect + (offset == -0x18 ? 0x3ea : 0x457), 
+    switch (yc_poly_emulator(ctx, fbuf, ofilesize, fbuf + ycsect + (offset == -0x18 ? 0x3ea : 0x457), 
 			 fbuf + sections[i].raw, 
 			 sections[i].ursz, 
-			 max_emu))
-      return 1;
+			 max_emu)) {
+    case 2:
+        return CL_VIRUS;
+    case 1:
+        return CL_EUNPACK;
+    }
   }
 
   /* Remove yC section */
@@ -243,7 +305,7 @@ int yc_decrypt(char *fbuf, unsigned int filesize, struct cli_exe_section *sectio
 
   if (cli_writen(desc, fbuf, filesize)==-1) {
     cli_dbgmsg("yC: Cannot write unpacked file\n");
-    return 1;
+    return CL_EUNPACK;
   }
-  return 0;
+  return CL_SUCCESS;
 }
