@@ -13,9 +13,9 @@
 #include <dirent.h>
 #include <sys/mman.h>
 
-#include <openssl/ssl.h>
-#include <openssl/err.h>
-#include "libclamav/crypto.h"
+#if HAVE_LIBXML2
+#include <libxml/parser.h>
+#endif
 
 #include "../libclamav/clamav.h"
 #include "../libclamav/others.h"
@@ -160,7 +160,7 @@ static int get_test_file(int i, char *file, unsigned fsize, unsigned long *size)
 static struct cl_engine *g_engine;
 
 #ifdef CHECK_HAVE_LOOPS
-/* int cl_scandesc(int desc, const char **virname, unsigned long int *scanned, const struct cl_engine *engine, const struct cl_limits *limits, unsigned int options) */
+/* int cl_scandesc(int desc, const char **virname, unsigned long int *scanned, const struct cl_engine *engine, const struct cl_limits *limits, struct cl_scan_options* options) */
 START_TEST (test_cl_scandesc)
 {
     const char *virname = NULL;
@@ -168,10 +168,14 @@ START_TEST (test_cl_scandesc)
     unsigned long size;
     unsigned long int scanned = 0;
     int ret;
+    struct cl_scan_options options;
+
+    memset(&options, 0, sizeof(struct cl_scan_options));
+    options.parse |= ~0;
 
     int fd = get_test_file(_i, file, sizeof(file), &size);
     cli_dbgmsg("scanning (scandesc) %s\n", file);
-    ret = cl_scandesc(fd, &virname, &scanned, g_engine, CL_SCAN_STDOPT);
+    ret = cl_scandesc(fd, file, &virname, &scanned, g_engine, &options);
     cli_dbgmsg("scan end (scandesc) %s\n", file);
 
     if (!FALSE_NEGATIVE) {
@@ -185,23 +189,25 @@ END_TEST
 START_TEST (test_cl_scandesc_allscan)
 {
     const char *virname = NULL;
-    const char ** virpp = &virname;
     char file[256];
     unsigned long size;
     unsigned long int scanned = 0;
     int ret;
+    struct cl_scan_options options;
+
+    memset(&options, 0, sizeof(struct cl_scan_options));
+    options.parse |= ~0;
+    options.general |= CL_SCAN_GENERAL_ALLMATCHES;
 
     int fd = get_test_file(_i, file, sizeof(file), &size);
     cli_dbgmsg("scanning (scandesc) %s\n", file);
-    ret = cl_scandesc(fd, virpp, &scanned, g_engine, CL_SCAN_ALLMATCHES+CL_SCAN_STDOPT);
+    ret = cl_scandesc(fd, file, &virname, &scanned, g_engine, &options);
 
     cli_dbgmsg("scan end (scandesc) %s\n", file);
 
     if (!FALSE_NEGATIVE) {
       fail_unless_fmt(ret == CL_VIRUS, "cl_scandesc_allscan failed for %s: %s", file, cl_strerror(ret));
-      virpp = (const char **)*virpp; /* allscan api hack */
-      fail_unless_fmt(*virpp && !strcmp(*virpp, "ClamAV-Test-File.UNOFFICIAL"), "virusname: %s", *virpp);
-      free((void *)virpp);
+      fail_unless_fmt(virname && !strcmp(virname, "ClamAV-Test-File.UNOFFICIAL"), "virusname: %s", virname);
     }
     close(fd);
 }
@@ -215,12 +221,16 @@ START_TEST (test_cl_scanfile)
     unsigned long size;
     unsigned long int scanned = 0;
     int ret;
+    struct cl_scan_options options;
+
+    memset(&options, 0, sizeof(struct cl_scan_options));
+    options.parse |= ~0;
 
     int fd = get_test_file(_i, file, sizeof(file), &size);
     close(fd);
 
     cli_dbgmsg("scanning (scanfile) %s\n", file);
-    ret = cl_scanfile(file, &virname, &scanned, g_engine, CL_SCAN_STDOPT);
+    ret = cl_scanfile(file, &virname, &scanned, g_engine, &options);
     cli_dbgmsg("scan end (scanfile) %s\n", file);
 
     if (!FALSE_NEGATIVE) {
@@ -233,24 +243,26 @@ END_TEST
 START_TEST (test_cl_scanfile_allscan)
 {
     const char *virname = NULL;
-    const char **virpp = &virname;
     char file[256];
     unsigned long size;
     unsigned long int scanned = 0;
     int ret;
+    struct cl_scan_options options;
+
+    memset(&options, 0, sizeof(struct cl_scan_options));
+    options.parse |= ~0;
+    options.general |= CL_SCAN_GENERAL_ALLMATCHES;
 
     int fd = get_test_file(_i, file, sizeof(file), &size);
     close(fd);
 
     cli_dbgmsg("scanning (scanfile_allscan) %s\n", file);
-    ret = cl_scanfile(file, virpp, &scanned, g_engine, CL_SCAN_ALLMATCHES+CL_SCAN_STDOPT);
+    ret = cl_scanfile(file, &virname, &scanned, g_engine, &options);
     cli_dbgmsg("scan end (scanfile_allscan) %s\n", file);
 
     if (!FALSE_NEGATIVE) {
       fail_unless_fmt(ret == CL_VIRUS, "cl_scanfile_allscan failed for %s: %s", file, cl_strerror(ret));
-      virpp = (const char **)*virpp; /* allscan api hack */
-      fail_unless_fmt(*virpp && !strcmp(*virpp, "ClamAV-Test-File.UNOFFICIAL"), "virusname: %s", *virpp);
-      free((void *)virpp);
+      fail_unless_fmt(virname && !strcmp(virname, "ClamAV-Test-File.UNOFFICIAL"), "virusname: %s", virname);
     }
 }
 END_TEST
@@ -262,13 +274,17 @@ START_TEST (test_cl_scanfile_callback)
     unsigned long size;
     unsigned long int scanned = 0;
     int ret;
+    struct cl_scan_options options;
+
+    memset(&options, 0, sizeof(struct cl_scan_options));
+    options.parse |= ~0;
 
     int fd = get_test_file(_i, file, sizeof(file), &size);
     close(fd);
 
     cli_dbgmsg("scanning (scanfile_cb) %s\n", file);
     /* TODO: test callbacks */
-    ret = cl_scanfile_callback(file, &virname, &scanned, g_engine, CL_SCAN_STDOPT, NULL);
+    ret = cl_scanfile_callback(file, &virname, &scanned, g_engine, &options, NULL);
     cli_dbgmsg("scan end (scanfile_cb) %s\n", file);
 
     if (!FALSE_NEGATIVE) {
@@ -281,25 +297,27 @@ END_TEST
 START_TEST (test_cl_scanfile_callback_allscan)
 {
     const char *virname = NULL;
-    const char **virpp = &virname;
     char file[256];
     unsigned long size;
     unsigned long int scanned = 0;
     int ret;
+    struct cl_scan_options options;
+
+    memset(&options, 0, sizeof(struct cl_scan_options));
+    options.parse |= ~0;
+    options.general |= CL_SCAN_GENERAL_ALLMATCHES;
 
     int fd = get_test_file(_i, file, sizeof(file), &size);
     close(fd);
 
     cli_dbgmsg("scanning (scanfile_cb_allscan) %s\n", file);
     /* TODO: test callbacks */
-    ret = cl_scanfile_callback(file, virpp, &scanned, g_engine, CL_SCAN_ALLMATCHES+CL_SCAN_STDOPT, NULL);
+    ret = cl_scanfile_callback(file, &virname, &scanned, g_engine, &options, NULL);
     cli_dbgmsg("scan end (scanfile_cb_allscan) %s\n", file);
 
     if (!FALSE_NEGATIVE) {
       fail_unless_fmt(ret == CL_VIRUS, "cl_scanfile_cb_allscan failed for %s: %s", file, cl_strerror(ret));
-      virpp = (const char **)*virpp; /* allscan api hack */
-      fail_unless_fmt(*virpp && !strcmp(*virpp, "ClamAV-Test-File.UNOFFICIAL"), "virusname: %s", *virpp);
-      free((void *)virpp);
+      fail_unless_fmt(virname && !strcmp(virname, "ClamAV-Test-File.UNOFFICIAL"), "virusname: %s", virname);
     }
 }
 END_TEST
@@ -311,12 +329,16 @@ START_TEST (test_cl_scandesc_callback)
     unsigned long size;
     unsigned long int scanned = 0;
     int ret;
+    struct cl_scan_options options;
+
+    memset(&options, 0, sizeof(struct cl_scan_options));
+    options.parse |= ~0;
 
     int fd = get_test_file(_i, file, sizeof(file), &size);
 
     cli_dbgmsg("scanning (scandesc_cb) %s\n", file);
     /* TODO: test callbacks */
-    ret = cl_scandesc_callback(fd, &virname, &scanned, g_engine, CL_SCAN_STDOPT, NULL);
+    ret = cl_scandesc_callback(fd, file, &virname, &scanned, g_engine, &options, NULL);
     cli_dbgmsg("scan end (scandesc_cb) %s\n", file);
 
     if (!FALSE_NEGATIVE) {
@@ -330,24 +352,26 @@ END_TEST
 START_TEST (test_cl_scandesc_callback_allscan)
 {
     const char *virname = NULL;
-    const char **virpp = &virname;
     char file[256];
     unsigned long size;
     unsigned long int scanned = 0;
     int ret;
+    struct cl_scan_options options;
+
+    memset(&options, 0, sizeof(struct cl_scan_options));
+    options.parse |= ~0;
+    options.general |= CL_SCAN_GENERAL_ALLMATCHES;
 
     int fd = get_test_file(_i, file, sizeof(file), &size);
 
     cli_dbgmsg("scanning (scandesc_cb_allscan) %s\n", file);
     /* TODO: test callbacks */
-    ret = cl_scandesc_callback(fd, virpp, &scanned, g_engine, CL_SCAN_ALLMATCHES+CL_SCAN_STDOPT, NULL);
+    ret = cl_scandesc_callback(fd, file, &virname, &scanned, g_engine, &options, NULL);
     cli_dbgmsg("scan end (scandesc_cb_allscan) %s\n", file);
 
     if (!FALSE_NEGATIVE) {
       fail_unless_fmt(ret == CL_VIRUS, "cl_scanfile_allscan failed for %s: %s", file, cl_strerror(ret));
-      virpp = (const char **)*virpp; /* allscan api hack */
-      fail_unless_fmt(*virpp && !strcmp(*virpp, "ClamAV-Test-File.UNOFFICIAL"), "virusname: %s", *virpp);
-      free((void *)virpp);
+      fail_unless_fmt(virname && !strcmp(virname, "ClamAV-Test-File.UNOFFICIAL"), "virusname: %s", virname);
     }
     close(fd);
 }
@@ -502,6 +526,10 @@ START_TEST (test_cl_scanmap_callback_handle)
     int ret;
     char file[256];
     unsigned long size;
+    struct cl_scan_options options;
+
+    memset(&options, 0, sizeof(struct cl_scan_options));
+    options.parse |= ~0;
 
     int fd = get_test_file(_i, file, sizeof(file), &size);
     /* intentionally use different way than scanners.c for testing */
@@ -509,7 +537,7 @@ START_TEST (test_cl_scanmap_callback_handle)
     fail_unless(!!map, "cl_fmap_open_handle");
 
     cli_dbgmsg("scanning (handle) %s\n", file);
-    ret = cl_scanmap_callback(map, &virname, &scanned, g_engine, CL_SCAN_STDOPT, NULL);
+    ret = cl_scanmap_callback(map, file, &virname, &scanned, g_engine, &options, NULL);
     cli_dbgmsg("scan end (handle) %s\n", file);
 
     if (!FALSE_NEGATIVE) {
@@ -523,12 +551,16 @@ END_TEST
 START_TEST (test_cl_scanmap_callback_handle_allscan)
 {
     const char *virname = NULL;
-    const char ** virpp = &virname;
     unsigned long int scanned = 0;
     cl_fmap_t *map;
     int ret;
     char file[256];
     unsigned long size;
+    struct cl_scan_options options;
+
+    memset(&options, 0, sizeof(struct cl_scan_options));
+    options.parse |= ~0;
+    options.general |= CL_SCAN_GENERAL_ALLMATCHES;
 
     int fd = get_test_file(_i, file, sizeof(file), &size);
     /* intentionally use different way than scanners.c for testing */
@@ -536,14 +568,12 @@ START_TEST (test_cl_scanmap_callback_handle_allscan)
     fail_unless(!!map, "cl_fmap_open_handle %s");
 
     cli_dbgmsg("scanning (handle) allscan %s\n", file);
-    ret = cl_scanmap_callback(map, virpp, &scanned, g_engine, CL_SCAN_ALLMATCHES+CL_SCAN_STDOPT, NULL);
+    ret = cl_scanmap_callback(map, file, &virname, &scanned, g_engine, &options, NULL);
     cli_dbgmsg("scan end (handle) allscan %s\n", file);
 
     if (!FALSE_NEGATIVE) {
-      fail_unless_fmt(ret == CL_VIRUS, "cl_scanmap_callback_allscan failed for %s: %s", file, cl_strerror(ret));
-      virpp = (const char **)*virpp; /* allscan api hack */
-      fail_unless_fmt(*virpp && !strcmp(*virpp, "ClamAV-Test-File.UNOFFICIAL"), "virusname: %s", *virpp);
-      free((void *)virpp);
+      fail_unless_fmt(ret == CL_VIRUS, "cl_scanmap_callback allscan failed for %s: %s", file, cl_strerror(ret));
+      fail_unless_fmt(virname && !strcmp(virname, "ClamAV-Test-File.UNOFFICIAL"), "virusname: %s", virname);
     }
     close(fd);
 }
@@ -558,6 +588,10 @@ START_TEST (test_cl_scanmap_callback_mem)
     void *mem;
     unsigned long size;
     char file[256];
+    struct cl_scan_options options;
+
+    memset(&options, 0, sizeof(struct cl_scan_options));
+    options.parse |= ~0;
 
     int fd = get_test_file(_i, file, sizeof(file), &size);
 
@@ -569,7 +603,7 @@ START_TEST (test_cl_scanmap_callback_mem)
     fail_unless(!!map, "cl_fmap_open_mem");
 
     cli_dbgmsg("scanning (mem) %s\n", file);
-    ret = cl_scanmap_callback(map, &virname, &scanned, g_engine, CL_SCAN_STDOPT, NULL);
+    ret = cl_scanmap_callback(map, file, &virname, &scanned, g_engine, &options, NULL);
     cli_dbgmsg("scan end (mem) %s\n", file);
     if (!FALSE_NEGATIVE) {
       fail_unless_fmt(ret == CL_VIRUS, "cl_scanmap_callback failed for %s: %s", file, cl_strerror(ret));
@@ -585,13 +619,17 @@ END_TEST
 START_TEST (test_cl_scanmap_callback_mem_allscan)
 {
     const char *virname = NULL;
-    const char **virpp = &virname;
     unsigned long int scanned = 0;
     cl_fmap_t *map;
     int ret;
     void *mem;
     unsigned long size;
     char file[256];
+    struct cl_scan_options options;
+
+    memset(&options, 0, sizeof(struct cl_scan_options));
+    options.parse |= ~0;
+    options.general |= CL_SCAN_GENERAL_ALLMATCHES;
 
     int fd = get_test_file(_i, file, sizeof(file), &size);
 
@@ -603,13 +641,11 @@ START_TEST (test_cl_scanmap_callback_mem_allscan)
     fail_unless(!!map, "cl_fmap_open_mem %s");
 
     cli_dbgmsg("scanning (mem) allscan %s\n", file);
-    ret = cl_scanmap_callback(map, virpp, &scanned, g_engine, CL_SCAN_ALLMATCHES+CL_SCAN_STDOPT, NULL);
+    ret = cl_scanmap_callback(map, file, &virname, &scanned, g_engine, &options, NULL);
     cli_dbgmsg("scan end (mem) allscan %s\n", file);
     if (!FALSE_NEGATIVE) {
-      fail_unless_fmt(ret == CL_VIRUS, "cl_scanmap_callback failed for %s: %s", file, cl_strerror(ret));
-      virpp = (const char **)*virpp; /* allscan api hack */
-      fail_unless_fmt(*virpp && !strcmp(*virpp, "ClamAV-Test-File.UNOFFICIAL"), "virusname: %s for %s", *virpp, file);
-      free((void *)virpp);
+      fail_unless_fmt(ret == CL_VIRUS, "cl_scanmap_callback allscan failed for %s: %s", file, cl_strerror(ret));
+      fail_unless_fmt(virname && !strcmp(virname, "ClamAV-Test-File.UNOFFICIAL"), "virusname: %s for %s", virname, file);
     }
     close(fd);
     cl_fmap_close(map);
@@ -623,6 +659,7 @@ static Suite *test_cl_suite(void)
     Suite *s = suite_create("cl_api");
     TCase *tc_cl = tcase_create("cl_dup");
     TCase *tc_cl_scan = tcase_create("cl_scan");
+    char *user_timeout = NULL;
     int expect = expected_testfiles;
     suite_add_tcase (s, tc_cl);
     tcase_add_test(tc_cl, test_cl_free);
@@ -661,6 +698,15 @@ static Suite *test_cl_suite(void)
     tcase_add_loop_test(tc_cl_scan, test_cl_scanmap_callback_handle_allscan, 0, expect);
     tcase_add_loop_test(tc_cl_scan, test_cl_scanmap_callback_mem, 0, expect);
     tcase_add_loop_test(tc_cl_scan, test_cl_scanmap_callback_mem_allscan, 0, expect);
+
+    user_timeout = getenv("T");
+    if (user_timeout) {
+        int timeout = atoi(user_timeout);
+        tcase_set_timeout(tc_cl_scan, timeout);
+	printf("Using test case timeout of %d seconds set by user\n", timeout);
+    } else {
+	printf("Using default test timeout; alter by setting 'T' env var (in seconds)\n");
+    }
 #endif
     return s;
 }
@@ -1016,8 +1062,13 @@ int main(void)
 
     srunner_run_all(sr, CK_NORMAL);
     nf = srunner_ntests_failed(sr);
+    if (nf)
+	printf("NOTICE: Use the 'T' environment variable to adjust testcase timeout\n");
     srunner_free(sr);
 
+#if HAVE_LIBXML2
+    xmlCleanupParser();
+#endif
     cl_cleanup_crypto();
 
     return (nf == 0) ? EXIT_SUCCESS : EXIT_FAILURE;
